==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkEnSightWriter.java <==
// java wrapper for vtkEnSightWriter object
//

package vtk;
import vtk.*;

public class vtkEnSightWriter extends vtkWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetProcessNumber_2(int id0);
  public void SetProcessNumber(int id0)
    { SetProcessNumber_2(id0); }

  private native int GetProcessNumber_3();
  public int GetProcessNumber()
    { return GetProcessNumber_3(); }

  private native void SetPath_4(String id0);
  public void SetPath(String id0)
    { SetPath_4(id0); }

  private native String GetPath_5();
  public String GetPath()
    { return GetPath_5(); }

  private native void SetBaseName_6(String id0);
  public void SetBaseName(String id0)
    { SetBaseName_6(id0); }

  private native String GetBaseName_7();
  public String GetBaseName()
    { return GetBaseName_7(); }

  private native void SetFileName_8(String id0);
  public void SetFileName(String id0)
    { SetFileName_8(id0); }

  private native String GetFileName_9();
  public String GetFileName()
    { return GetFileName_9(); }

  private native void SetTimeStep_10(int id0);
  public void SetTimeStep(int id0)
    { SetTimeStep_10(id0); }

  private native int GetTimeStep_11();
  public int GetTimeStep()
    { return GetTimeStep_11(); }

  private native void SetGhostLevel_12(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_12(id0); }

  private native int GetGhostLevel_13();
  public int GetGhostLevel()
    { return GetGhostLevel_13(); }

  private native void SetTransientGeometry_14(boolean id0);
  public void SetTransientGeometry(boolean id0)
    { SetTransientGeometry_14(id0); }

  private native boolean GetTransientGeometry_15();
  public boolean GetTransientGeometry()
    { return GetTransientGeometry_15(); }

  private native void SetNumberOfBlocks_16(int id0);
  public void SetNumberOfBlocks(int id0)
    { SetNumberOfBlocks_16(id0); }

  private native int GetNumberOfBlocks_17();
  public int GetNumberOfBlocks()
    { return GetNumberOfBlocks_17(); }

  private native void SetInputData_18(vtkUnstructuredGrid id0);
  public void SetInputData(vtkUnstructuredGrid id0)
    { SetInputData_18(id0); }

  private native long GetInput_19();
  public vtkUnstructuredGrid GetInput() {
    long temp = GetInput_19();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void WriteCaseFile_20(int id0);
  public void WriteCaseFile(int id0)
    { WriteCaseFile_20(id0); }

  private native void WriteSOSCaseFile_21(int id0);
  public void WriteSOSCaseFile(int id0)
    { WriteSOSCaseFile_21(id0); }

  public vtkEnSightWriter() { super(); }

  public vtkEnSightWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-aarch64.pkg.tar.xz: vtk/vtkEnSightWriter.java <==
// java wrapper for vtkEnSightWriter object
//

package vtk;
import vtk.*;

public class vtkEnSightWriter extends vtkWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetProcessNumber_2(int id0);
  public void SetProcessNumber(int id0)
    { SetProcessNumber_2(id0); }

  private native int GetProcessNumber_3();
  public int GetProcessNumber()
    { return GetProcessNumber_3(); }

  private native void SetPath_4(String id0);
  public void SetPath(String id0)
    { SetPath_4(id0); }

  private native String GetPath_5();
  public String GetPath()
    { return GetPath_5(); }

  private native void SetBaseName_6(String id0);
  public void SetBaseName(String id0)
    { SetBaseName_6(id0); }

  private native String GetBaseName_7();
  public String GetBaseName()
    { return GetBaseName_7(); }

  private native void SetFileName_8(String id0);
  public void SetFileName(String id0)
    { SetFileName_8(id0); }

  private native String GetFileName_9();
  public String GetFileName()
    { return GetFileName_9(); }

  private native void SetTimeStep_10(int id0);
  public void SetTimeStep(int id0)
    { SetTimeStep_10(id0); }

  private native int GetTimeStep_11();
  public int GetTimeStep()
    { return GetTimeStep_11(); }

  private native void SetGhostLevel_12(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_12(id0); }

  private native int GetGhostLevel_13();
  public int GetGhostLevel()
    { return GetGhostLevel_13(); }

  private native void SetTransientGeometry_14(boolean id0);
  public void SetTransientGeometry(boolean id0)
    { SetTransientGeometry_14(id0); }

  private native boolean GetTransientGeometry_15();
  public boolean GetTransientGeometry()
    { return GetTransientGeometry_15(); }

  private native void SetNumberOfBlocks_16(int id0);
  public void SetNumberOfBlocks(int id0)
    { SetNumberOfBlocks_16(id0); }

  private native int GetNumberOfBlocks_17();
  public int GetNumberOfBlocks()
    { return GetNumberOfBlocks_17(); }

  private native void SetInputData_18(vtkUnstructuredGrid id0);
  public void SetInputData(vtkUnstructuredGrid id0)
    { SetInputData_18(id0); }

  private native long GetInput_19();
  public vtkUnstructuredGrid GetInput() {
    long temp = GetInput_19();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void WriteCaseFile_20(int id0);
  public void WriteCaseFile(int id0)
    { WriteCaseFile_20(id0); }

  private native void WriteSOSCaseFile_21(int id0);
  public void WriteSOSCaseFile(int id0)
    { WriteSOSCaseFile_21(id0); }

  public vtkEnSightWriter() { super(); }

  public vtkEnSightWriter(long id) { super(id); }
  public native long   VTKInit();

}
